import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';
import { globalRoutes, indexRoutes} from '@/router'

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/dstindex/:dstindex?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'dstindex';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: 'app.views.dstindex.caption',
                info:'',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'dstindex', parameterName: 'dstindex' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/lite/dst-index/dst-index.vue'),
            children: [
                {
                    path: 'dstdatasources/:dstdatasource?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.dstdatasource.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-data-source-pickup-grid-view/dst-data-source-pickup-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metarelationships/:metarelationship?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
                },
                {
                    path: 'metarelationships/:metarelationship?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
                },
                {
                    path: 'metamodels/:metamodel?/editview/:editview?',
                    meta: {
                        caption: 'entities.metamodel.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodels', parameterName: 'metamodel' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-model-edit-view/meta-model-edit-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metarelationships/:metarelationship?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
                },
                {
                    path: 'metarelationships/:metarelationship?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metadatasets/:metadataset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metadataset.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metadatasets/:metadataset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metadataset.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
                },
                {
                    path: 'metadatasets/:metadataset?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metadataset.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metadatasets/:metadataset?/editview/:editview?',
                    meta: {
                        caption: 'entities.metadataset.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metadatasets/:metadataset?/editview/:editview?',
                    meta: {
                        caption: 'entities.metadataset.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
                },
                {
                    path: 'metadatasets/:metadataset?/editview/:editview?',
                    meta: {
                        caption: 'entities.metadataset.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metadatasets', parameterName: 'metadataset' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metafields/:metafield?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
                },
                {
                    path: 'metafields/:metafield?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metafields/:metafield?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
                },
                {
                    path: 'metafields/:metafield?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metafield.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
                },
                {
                    path: 'metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metarelationship.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
                },
                {
                    path: 'metamodels/:metamodel?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metamodel.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metamodels', parameterName: 'metamodel' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-model-grid-view/meta-model-grid-view.vue'),
                },
                {
                    path: 'dstdatasources/:dstdatasource?/editview/:editview?',
                    meta: {
                        caption: 'entities.dstdatasource.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-data-source-edit-view/dst-data-source-edit-view.vue'),
                },
                {
                    path: 'dstdatasources/:dstdatasource?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.dstdatasource.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-data-source-pickup-view/dst-data-source-pickup-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metaentity.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-pickup-grid-view/meta-entity-pickup-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'entities.metaentity.views.pickupgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-pickup-grid-view/meta-entity-pickup-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/editview/:editview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metarelationships/:metarelationship?/editview/:editview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
                },
                {
                    path: 'metarelationships/:metarelationship?/editview/:editview?',
                    meta: {
                        caption: 'entities.metarelationship.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metarelationships', parameterName: 'metarelationship' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/editview/:editview?',
                    meta: {
                        caption: 'entities.metaentity.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-edit-view/meta-entity-edit-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/editview/:editview?',
                    meta: {
                        caption: 'entities.metaentity.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-edit-view/meta-entity-edit-view.vue'),
                },
                {
                    path: 'dstdatasources/:dstdatasource?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.dstdatasource.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/dst-data-source-grid-view/dst-data-source-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metafield.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metafields/:metafield?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metafield.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
                },
                {
                    path: 'metafields/:metafield?/editgridview/:editgridview?',
                    meta: {
                        caption: 'entities.metafield.views.editgridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editgridview', parameterName: 'editgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/editview/:editview?',
                    meta: {
                        caption: 'entities.metafield.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/metafields/:metafield?/editview/:editview?',
                    meta: {
                        caption: 'entities.metafield.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
                },
                {
                    path: 'metafields/:metafield?/editview/:editview?',
                    meta: {
                        caption: 'entities.metafield.views.editview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metafields', parameterName: 'metafield' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metaentity.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-pickup-view/meta-entity-pickup-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/pickupview/:pickupview?',
                    meta: {
                        caption: 'entities.metaentity.views.pickupview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-pickup-view/meta-entity-pickup-view.vue'),
                },
                {
                    path: 'dstsystems/:dstsystem?/metaentities/:metaentity?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metaentity.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'dstsystems', parameterName: 'dstsystem' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-grid-view/meta-entity-grid-view.vue'),
                },
                {
                    path: 'metaentities/:metaentity?/gridview/:gridview?',
                    meta: {
                        caption: 'entities.metaentity.views.gridview.caption',
                        info:'',
                        parameters: [
                            { pathName: 'dstindex', parameterName: 'dstindex' },
                            { pathName: 'metaentities', parameterName: 'metaentity' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/lite/meta-entity-grid-view/meta-entity-grid-view.vue'),
                },
            ...indexRoutes,
            ],
        },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
    },
    {
        path: '/metarelationships/:metarelationship?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-grid-view/meta-relationship-pickup-grid-view.vue'),
    },
    {
        path: '/dstdatasources/:dstdatasource?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.dstdatasource.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-data-source-pickup-view/dst-data-source-pickup-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metarelationships/:metarelationship?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
    },
    {
        path: '/metarelationships/:metarelationship?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metarelationship.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-pickup-view/meta-relationship-pickup-view.vue'),
    },
    {
        path: '/dstdatasources/:dstdatasource?/editview/:editview?',
        meta: {
            caption: 'entities.dstdatasource.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-data-source-edit-view/dst-data-source-edit-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metafield.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metafields/:metafield?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metafield.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
    },
    {
        path: '/metafields/:metafield?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metafield.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-grid-view/meta-field-edit-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metadatasets/:metadataset?/editview/:editview?',
        meta: {
            caption: 'entities.metadataset.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metadatasets/:metadataset?/editview/:editview?',
        meta: {
            caption: 'entities.metadataset.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
    },
    {
        path: '/metadatasets/:metadataset?/editview/:editview?',
        meta: {
            caption: 'entities.metadataset.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-edit-view/meta-data-set-edit-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metaentity.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-pickup-view/meta-entity-pickup-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metaentity.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-pickup-view/meta-entity-pickup-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/editview/:editview?',
        meta: {
            caption: 'entities.metaentity.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-edit-view/meta-entity-edit-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/editview/:editview?',
        meta: {
            caption: 'entities.metaentity.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-edit-view/meta-entity-edit-view.vue'),
    },
    {
        path: '/metamodels/:metamodel?/editview/:editview?',
        meta: {
            caption: 'entities.metamodel.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodels', parameterName: 'metamodel' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-model-edit-view/meta-model-edit-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metafield.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metafields/:metafield?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metafield.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
    },
    {
        path: '/metafields/:metafield?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metafield.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-grid-view/meta-field-pickup-grid-view.vue'),
    },
    {
        path: '/dstdatasources/:dstdatasource?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.dstdatasource.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-data-source-pickup-grid-view/dst-data-source-pickup-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/gridview/:gridview?',
        meta: {
            caption: 'entities.metaentity.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-grid-view/meta-entity-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/gridview/:gridview?',
        meta: {
            caption: 'entities.metaentity.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-grid-view/meta-entity-grid-view.vue'),
    },
    {
        path: '/dstdatasources/:dstdatasource?/gridview/:gridview?',
        meta: {
            caption: 'entities.dstdatasource.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstdatasources', parameterName: 'dstdatasource' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/dst-data-source-grid-view/dst-data-source-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metadatasets/:metadataset?/gridview/:gridview?',
        meta: {
            caption: 'entities.metadataset.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metadatasets/:metadataset?/gridview/:gridview?',
        meta: {
            caption: 'entities.metadataset.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
    },
    {
        path: '/metadatasets/:metadataset?/gridview/:gridview?',
        meta: {
            caption: 'entities.metadataset.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'metadatasets', parameterName: 'metadataset' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-data-set-grid-view/meta-data-set-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/editview/:editview?',
        meta: {
            caption: 'entities.metafield.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metafields/:metafield?/editview/:editview?',
        meta: {
            caption: 'entities.metafield.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
    },
    {
        path: '/metafields/:metafield?/editview/:editview?',
        meta: {
            caption: 'entities.metafield.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-edit-view/meta-field-edit-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metaentity.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-pickup-grid-view/meta-entity-pickup-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'entities.metaentity.views.pickupgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-entity-pickup-grid-view/meta-entity-pickup-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metafields/:metafield?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metafield.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metafields/:metafield?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metafield.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
    },
    {
        path: '/metafields/:metafield?/pickupview/:pickupview?',
        meta: {
            caption: 'entities.metafield.views.pickupview.caption',
            info:'',
            parameters: [
                { pathName: 'metafields', parameterName: 'metafield' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-field-pickup-view/meta-field-pickup-view.vue'),
    },
    {
        path: '/metamodels/:metamodel?/gridview/:gridview?',
        meta: {
            caption: 'entities.metamodel.views.gridview.caption',
            info:'',
            parameters: [
                { pathName: 'metamodels', parameterName: 'metamodel' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-model-grid-view/meta-model-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metarelationship.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metarelationships/:metarelationship?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metarelationship.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
    },
    {
        path: '/metarelationships/:metarelationship?/editgridview/:editgridview?',
        meta: {
            caption: 'entities.metarelationship.views.editgridview.caption',
            info:'',
            parameters: [
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editgridview', parameterName: 'editgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-grid-view/meta-relationship-edit-grid-view.vue'),
    },
    {
        path: '/dstsystems/:dstsystem?/metaentities/:metaentity?/metarelationships/:metarelationship?/editview/:editview?',
        meta: {
            caption: 'entities.metarelationship.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'dstsystems', parameterName: 'dstsystem' },
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
    },
    {
        path: '/metaentities/:metaentity?/metarelationships/:metarelationship?/editview/:editview?',
        meta: {
            caption: 'entities.metarelationship.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metaentities', parameterName: 'metaentity' },
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
    },
    {
        path: '/metarelationships/:metarelationship?/editview/:editview?',
        meta: {
            caption: 'entities.metarelationship.views.editview.caption',
            info:'',
            parameters: [
                { pathName: 'metarelationships', parameterName: 'metarelationship' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/lite/meta-relationship-edit-view/meta-relationship-edit-view.vue'),
    },
        ...globalRoutes,
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/lock',
            name: 'lock',
            meta: {  
                caption: '锁屏',
                viewType: 'lock',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                next();
            },
            component: () => import('@components/app-lock/app-lock.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'dstindex'
        },
    ],
});
// 解决路由跳转路由重复时报错
const originalPush = Router.prototype.push
Router.prototype.push = function push(location: any) {
    let result: any = originalPush.call(this, location);
    return result.catch((err: any) => err);
}
export default router;
